/*
 * Data from US Census Bureau
 * http://www.census.gov/population/international/data/idb
 */

%macro PopulationPyramid( census_dataset, country_name );

data work.pop_clean;
  set &census_dataset;
  percent_male = percent_male / 100;
  percent_female = percent_female / 100 ;
  if ( age = '(NA)' or age = 'Total' ) then delete;
run;

proc template;
  define statgraph pop_pyramid;
    begingraph / designHeight=640;
    
      discreteAttrMap name='year';
        value '1980' / lineAttrs=(color=cxff0000);
        value '1981' / lineAttrs=(color=cxff0300);
        value '1982' / lineAttrs=(color=cxff0700);
        value '1983' / lineattrs=(color=cxff0a00);
        value '1984' / lineattrs=(color=cxff0e00);
        value '1985' / lineattrs=(color=cxff1200);
        value '1986' / lineattrs=(color=cxff1500);
        value '1987' / lineattrs=(color=cxff1900);
        value '1988' / lineattrs=(color=cxff1d00);
        value '1989' / lineattrs=(color=cxff2000);
        value '1990' / lineattrs=(color=cxff2400);
        value '1991' / lineattrs=(color=cxff2800);
        value '1992' / lineattrs=(color=cxff2b00);
        value '1993' / lineattrs=(color=cxff2f00);
        value '1994' / lineattrs=(color=cxff3300);
        value '1995' / lineattrs=(color=cxff3600);
        value '1996' / lineattrs=(color=cxff3a00);
        value '1997' / lineattrs=(color=cxff3d00);
        value '1998' / lineattrs=(color=cxff4100);
        value '1999' / lineattrs=(color=cxff4500);
        value '2000' / lineattrs=(color=cxff4800);
        value '2001' / lineattrs=(color=cxff4c00);
        value '2002' / lineattrs=(color=cxff5000);
        value '2003' / lineattrs=(color=cxff5300);
        value '2004' / lineattrs=(color=cxff5700);
        value '2005' / lineattrs=(color=cxff5b00);
        value '2006' / lineattrs=(color=cxff5e00);
        value '2007' / lineattrs=(color=cxff6200);
        value '2008' / lineattrs=(color=cxff6600);
        value '2009' / lineattrs=(color=cxff6900);
        value '2010' / lineattrs=(color=cxff6d00);
        value '2011' / lineattrs=(color=cxff7000);
        value '2012' / lineattrs=(color=cxff7400);
        value '2013' / lineattrs=(color=cxff7800);
        value '2014' / lineattrs=(color=cxff7b00);
        value '2015' / lineattrs=(color=cxff7f00);
        value '2016' / lineattrs=(color=cxff8300);
        value '2017' / lineattrs=(color=cxff8600);
        value '2018' / lineattrs=(color=cxff8a00);
        value '2019' / lineattrs=(color=cxff8e00);
        value '2020' / lineattrs=(color=cxff9100);
        value '2021' / lineattrs=(color=cxff9500);
        value '2022' / lineattrs=(color=cxff9900);
        value '2023' / lineattrs=(color=cxff9c00);
        value '2024' / lineattrs=(color=cxffa000);
        value '2025' / lineattrs=(color=cxffa300);
        value '2026' / lineattrs=(color=cxffa700);
        value '2027' / lineattrs=(color=cxffab00);
        value '2028' / lineattrs=(color=cxffae00);
        value '2029' / lineattrs=(color=cxffb200);
        value '2030' / lineattrs=(color=cxffb600);
        value '2031' / lineattrs=(color=cxffb900);
        value '2032' / lineattrs=(color=cxffbd00);
        value '2033' / lineattrs=(color=cxffc100);
        value '2034' / lineattrs=(color=cxffc400);
        value '2035' / lineattrs=(color=cxffc800);
        value '2036' / lineattrs=(color=cxffcc00);
        value '2037' / lineattrs=(color=cxffcf00);
        value '2038' / lineattrs=(color=cxffd300);
        value '2039' / lineattrs=(color=cxffd600);
        value '2040' / lineattrs=(color=cxffda00);
        value '2041' / lineattrs=(color=cxffde00);
        value '2042' / lineattrs=(color=cxffe100);
        value '2043' / lineattrs=(color=cxffe500);
        value '2044' / lineattrs=(color=cxffe900);
        value '2045' / lineattrs=(color=cxffec00);
        value '2046' / lineattrs=(color=cxfff000);
        value '2047' / lineattrs=(color=cxfff400);
        value '2048' / lineattrs=(color=cxfff700);
        value '2049' / lineattrs=(color=cxfffb00);
        value '2050' / lineAttrs=(color=cxffff00);

        value other / lineAttrs=(color=cx000000);
      enddiscreteattrmap;
      discreteAttrVar attrVar=year_attrvar var=year attrmap="year";

%let TitleAttrs=(color=gray size=24);
%let TickValueAttrs=(color=gray);
%let XAxisLabelAttrs=(color=gray size=18);
      entrytitle halign=center "Population Distribution for " "&country_name" / textattrs=&TitleAttrs;
      layout lattice / columns=2 columnDataRange=unionAll columnWeights=(0.47 0.53);
        layout overlay / wallDisplay=none yaxisopts=(display=none)
              xaxisopts=(reverse=true display=(tickvalues)
                          linearopts=(tickValueFormat=percent. viewmin=0) labelAttrs=&XAxisLabelAttrs
                          tickvalueattrs=&TickValueAttrs) ;  
          entry halign=left 'Male' / valign=top textattrs=&XAxisLabelAttrs;
          seriesPlot x=Percent_Male y=Age / group=year_attrvar smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.4;
        endlayout;

        layout overlay / wallDisplay=none yaxisopts=(display=(tickvalues) tickvalueattrs=&TickValueAttrs)
                        xaxisopts=(linearopts=(tickValueFormat=percent. viewmin=0) labelAttrs=&XAxisLabelAttrs
                                    display=(tickvalues) tickvalueattrs=&TickValueAttrs);

          entry halign=right 'Female' / valign=top textattrs=&XAxisLabelattrs;
          seriesplot x=Percent_Female y=Age / group=year_attrvar smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.4;
        endlayout;

          
      endlayout;

      legendItem name='1980' type=line / label='1980' lineAttrs=(color=cxFF0000 thickness=2);
      legendItem name='2050' type=line / label='2050' lineAttrs=(color=cxFFFF00 thickness=2);
      layout globalLegend;
        discreteLegend '1980' '2050' / title="Year";
      endLayout;
    endGraph;
  end;
run;

ods graphics;
proc sgrender data=pop_clean template=pop_pyramid;
run;

%mend PopulationPyramid;

%PopulationPyramid(sasuser.usa_pop, USA);
