/*
 * Data from US Census Bureau
 * http://www.census.gov/population/international/data/idb
 */

/* Rename relevant columns with country suffix */
%macro pop_clean(cID);
data work.pop_clean_&cID;
  set sasuser.&cID._pop;
  keep year age percent_male percent_female;
  where age ne '(NA)' and age ne 'Total';
     
  percent_male = percent_male / 100;
  percent_female = percent_female / 100;

  rename year=year_&cID age=age_&cID
        percent_male=pct_male_&cID percent_female=pct_female_&cID;
run;
%mend pop_clean;

%let cName1="USA";
%let cName2="Qatar";

%let cID1=usa;
%let cID2=qatar;
%pop_clean(&cID1);
%pop_clean(&cID2);

data work.pop_clean_ovl;
  merge work.pop_clean_&cID1 work.pop_clean_&cID2;
run;

proc template;
  define statgraph pop_pyramid_ovl;
    begingraph / designHeight=640;

        /* Color */
      discreteattrmap name="year_&cID1";
        value '1980' / lineattrs=(color=cx0000FF);
        value '1981' / lineattrs=(color=cx0003FF);
        value '1982' / lineattrs=(color=cx0007FF);
        value '1983' / lineattrs=(color=cx000aFF);
        value '1984' / lineattrs=(color=cx000eFF);
        value '1985' / lineattrs=(color=cx0012FF);
        value '1986' / lineattrs=(color=cx0015FF);
        value '1987' / lineattrs=(color=cx0019FF);
        value '1988' / lineattrs=(color=cx001dFF);
        value '1989' / lineattrs=(color=cx0020FF);
        value '1990' / lineattrs=(color=cx0024FF);
        value '1991' / lineattrs=(color=cx0028FF);
        value '1992' / lineattrs=(color=cx002bFF);
        value '1993' / lineattrs=(color=cx002fFF);
        value '1994' / lineattrs=(color=cx0033FF);
        value '1995' / lineattrs=(color=cx0036FF);
        value '1996' / lineattrs=(color=cx003aFF);
        value '1997' / lineattrs=(color=cx003dFF);
        value '1998' / lineattrs=(color=cx0041FF);
        value '1999' / lineattrs=(color=cx0045FF);
        value '2000' / lineattrs=(color=cx0048FF);
        value '2001' / lineattrs=(color=cx004cFF);
        value '2002' / lineattrs=(color=cx0050FF);
        value '2003' / lineattrs=(color=cx0053FF);
        value '2004' / lineattrs=(color=cx0057FF);
        value '2005' / lineattrs=(color=cx005bFF);
        value '2006' / lineattrs=(color=cx005eFF);
        value '2007' / lineattrs=(color=cx0062FF);
        value '2008' / lineattrs=(color=cx0066FF);
        value '2009' / lineattrs=(color=cx0069FF);
        value '2010' / lineattrs=(color=cx006dFF);
        value '2011' / lineattrs=(color=cx0070FF);
        value '2012' / lineattrs=(color=cx0074FF);
        value '2013' / lineattrs=(color=cx0078FF);
        value '2014' / lineattrs=(color=cx007bFF);
        value '2015' / lineattrs=(color=cx007fFF);
        value '2016' / lineattrs=(color=cx0083FF);
        value '2017' / lineattrs=(color=cx0086FF);
        value '2018' / lineattrs=(color=cx008aFF);
        value '2019' / lineattrs=(color=cx008eFF);
        value '2020' / lineattrs=(color=cx0091FF);
        value '2021' / lineattrs=(color=cx0095FF);
        value '2022' / lineattrs=(color=cx0099FF);
        value '2023' / lineattrs=(color=cx009cFF);
        value '2024' / lineattrs=(color=cx00a0FF);
        value '2025' / lineattrs=(color=cx00a3FF);
        value '2026' / lineattrs=(color=cx00a7FF);
        value '2027' / lineattrs=(color=cx00abFF);
        value '2028' / lineattrs=(color=cx00aeFF);
        value '2029' / lineattrs=(color=cx00b2FF);
        value '2030' / lineattrs=(color=cx00b6FF);
        value '2031' / lineattrs=(color=cx00b9FF);
        value '2032' / lineattrs=(color=cx00bdFF);
        value '2033' / lineattrs=(color=cx00c1FF);
        value '2034' / lineattrs=(color=cx00c4FF);
        value '2035' / lineattrs=(color=cx00c8FF);
        value '2036' / lineattrs=(color=cx00ccFF);
        value '2037' / lineattrs=(color=cx00cfFF);
        value '2038' / lineattrs=(color=cx00d3FF);
        value '2039' / lineattrs=(color=cx00d6FF);
        value '2040' / lineattrs=(color=cx00daFF);
        value '2041' / lineattrs=(color=cx00deFF);
        value '2042' / lineattrs=(color=cx00e1FF);
        value '2043' / lineattrs=(color=cx00e5FF);
        value '2044' / lineattrs=(color=cx00e9FF);
        value '2045' / lineattrs=(color=cx00ecFF);
        value '2046' / lineattrs=(color=cx00f0FF);
        value '2047' / lineattrs=(color=cx00f4FF);
        value '2048' / lineattrs=(color=cx00f7FF);
        value '2049' / lineattrs=(color=cx00fbFF);
        value '2050' / lineattrs=(color=cx00ffFF);
      endDiscreteAttrMap;
      discreteAttrVar attrvar=av_year_&cID1 var=year_&cID1 attrmap="year_&cID1";

      discreteattrmap name="year_&cID2";
        value '1980' / lineattrs=(color=cxff0000);
        value '1981' / lineattrs=(color=cxff0300);
        value '1982' / lineattrs=(color=cxff0700);
        value '1983' / lineattrs=(color=cxff0a00);
        value '1984' / lineattrs=(color=cxff0e00);
        value '1985' / lineattrs=(color=cxff1200);
        value '1986' / lineattrs=(color=cxff1500);
        value '1987' / lineattrs=(color=cxff1900);
        value '1988' / lineattrs=(color=cxff1d00);
        value '1989' / lineattrs=(color=cxff2000);
        value '1990' / lineattrs=(color=cxff2400);
        value '1991' / lineattrs=(color=cxff2800);
        value '1992' / lineattrs=(color=cxff2b00);
        value '1993' / lineattrs=(color=cxff2f00);
        value '1994' / lineattrs=(color=cxff3300);
        value '1995' / lineattrs=(color=cxff3600);
        value '1996' / lineattrs=(color=cxff3a00);
        value '1997' / lineattrs=(color=cxff3d00);
        value '1998' / lineattrs=(color=cxff4100);
        value '1999' / lineattrs=(color=cxff4500);
        value '2000' / lineattrs=(color=cxff4800);
        value '2001' / lineattrs=(color=cxff4c00);
        value '2002' / lineattrs=(color=cxff5000);
        value '2003' / lineattrs=(color=cxff5300);
        value '2004' / lineattrs=(color=cxff5700);
        value '2005' / lineattrs=(color=cxff5b00);
        value '2006' / lineattrs=(color=cxff5e00);
        value '2007' / lineattrs=(color=cxff6200);
        value '2008' / lineattrs=(color=cxff6600);
        value '2009' / lineattrs=(color=cxff6900);
        value '2010' / lineattrs=(color=cxff6d00);
        value '2011' / lineattrs=(color=cxff7000);
        value '2012' / lineattrs=(color=cxff7400);
        value '2013' / lineattrs=(color=cxff7800);
        value '2014' / lineattrs=(color=cxff7b00);
        value '2015' / lineattrs=(color=cxff7f00);
        value '2016' / lineattrs=(color=cxff8300);
        value '2017' / lineattrs=(color=cxff8600);
        value '2018' / lineattrs=(color=cxff8a00);
        value '2019' / lineattrs=(color=cxff8e00);
        value '2020' / lineattrs=(color=cxff9100);
        value '2021' / lineattrs=(color=cxff9500);
        value '2022' / lineattrs=(color=cxff9900);
        value '2023' / lineattrs=(color=cxff9c00);
        value '2024' / lineattrs=(color=cxffa000);
        value '2025' / lineattrs=(color=cxffa300);
        value '2026' / lineattrs=(color=cxffa700);
        value '2027' / lineattrs=(color=cxffab00);
        value '2028' / lineattrs=(color=cxffae00);
        value '2029' / lineattrs=(color=cxffb200);
        value '2030' / lineattrs=(color=cxffb600);
        value '2031' / lineattrs=(color=cxffb900);
        value '2032' / lineattrs=(color=cxffbd00);
        value '2033' / lineattrs=(color=cxffc100);
        value '2034' / lineattrs=(color=cxffc400);
        value '2035' / lineattrs=(color=cxffc800);
        value '2036' / lineattrs=(color=cxffcc00);
        value '2037' / lineattrs=(color=cxffcf00);
        value '2038' / lineattrs=(color=cxffd300);
        value '2039' / lineattrs=(color=cxffd600);
        value '2040' / lineattrs=(color=cxffda00);
        value '2041' / lineattrs=(color=cxffde00);
        value '2042' / lineattrs=(color=cxffe100);
        value '2043' / lineattrs=(color=cxffe500);
        value '2044' / lineattrs=(color=cxffe900);
        value '2045' / lineattrs=(color=cxffec00);
        value '2046' / lineattrs=(color=cxfff000);
        value '2047' / lineattrs=(color=cxfff400);
        value '2048' / lineattrs=(color=cxfff700);
        value '2049' / lineattrs=(color=cxfffb00);
        value '2050' / lineattrs=(color=cxffff00);
      endDiscreteAttrMap;
      discreteAttrVar attrVar=av_year_&cID2 var=year_&cID2 attrMap="year_&cID2";

%let TickValueAttrs=(color=gray size=8);
%let XAxisLabelAttrs=(color=gray size=10);
      entrytitle halign=center "Population Distribution by Age";
      layout lattice / columns=2 columnDataRange=unionAll columnWeights=(0.47 0.53);
        layout overlay / wallDisplay=none yaxisopts=(display=none)
                        xaxisopts=(reverse=true display=(tickvalues)
                        linearopts=(tickValueFormat=percent. viewmin=0) labelAttrs=&XAxisLabelAttrs
                        tickvalueattrs=&TickValueAttrs) ;

          entry halign=left 'Male' / valign=top textattrs=&XAxisLabelAttrs;
          seriesPlot x=pct_male_&cID1 y=age_&cID1 / group=av_year_&cID1 smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.6;
          seriesPlot x=pct_male_&cID2 y=age_&cID2 / group=av_year_&cID2 smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.3;
        endlayout;

        layout overlay / wallDisplay=none yaxisopts=(display=(tickvalues) tickvalueattrs=&TickValueAttrs)
                        xaxisopts=(linearopts=(tickValueFormat=percent. viewmin=0) labelAttrs=&XAxisLabelAttrs
                                    display=(tickvalues) tickvalueattrs=&TickValueAttrs);

          entry halign=right 'Female' / valign=top textattrs=&XAxisLabelattrs;          
          seriesplot x=pct_female_&cID1 y=age_&cID1 / group=av_year_&cID1 smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.6;
          seriesplot x=pct_female_&cID2 y=age_&cID2 / group=av_year_&cID2 smoothconnect=true
              lineattrs=(pattern=solid thickness=2) dataTransparency=0.3;
        endlayout;

      endlayout;

      legendItem name='1980_&cID1' type=line / label='1980' lineAttrs=(color=cxFF0000 thickness=2);
      legendItem name='2050_&cID1' type=line / label='2050' lineAttrs=(color=cxFFFF00 thickness=2);

      legendItem name='1980_&cID2' type=line / label='1980' lineAttrs=(color=cx0000FF thickness=2);
      legendItem name='2050_&cID2' type=line / label='2050' lineAttrs=(color=cx00FFFF thickness=2);
      layout globalLegend / borderAttrs=(color=lightGray);
        discreteLegend '1980_&cID2' '2050_&cID2' / title=&cName1;
        discreteLegend '1980_&cID1' '2050_&cID1' / title=&cName2;
      endLayout;
      entryFootnote halign=left "As seen on: "
          "http://www.excelcharts.com/"
          "blog/beautiful-but-terrible-population-pyramids/"
          "   Data: U.S. Census Bureau" / textAttrs=graphDataText;
    endgraph;
  end;
run;

ods graphics / antialiasmax=50000 imagename="PopPyramid_Ovl";
proc sgrender data=pop_clean_ovl template=pop_pyramid_ovl;
run;
