
/* Data is approximate and for illustration only. */
data state_online;
  input State $1-10 stateAbbr $15-20 Case $21-35 Amount;
  format Amount dollar6.0;
  label amount='Amount in Billions';
  datalines;
California    CA    Online          2.0 
California    CA    Out-of-State    2.2
California    CA    Net Shortfall   23.0
New Jersey    NJ    Online          0.2
New Jersey    NJ    Out-of-State    0.2
New Jersey    NJ    Net Shortfall   9.6
New York      NY    Online          0.9
New York      NY    Out-of-State    1.0
New York      NY    Net Shortfall   8.1
Texas         TX    Online          0.9
Texas         TX    Out-of-State    1.0
Texas         TX    Net Shortfall   6.0
Illinois      IL    Online          0.4
Illinois      IL    Out-of-State    0.7
Illinois      IL    Net Shortfall   4.3
Minnesota     MN    Online          0.2
Minnesota     MN    Out-of-State    0.2
Minnesota     MN    Net Shortfall   3.0
Florida       FL    Online          0.7
Florida       FL    Out-of-State    0.6
Florida       FL    Net Shortfall   2.1
Penn.         PA    Online          0.3
Penn.         PA    Out-of-State    0.3
Penn.         PA    Net Shortfall   2.8
Ohio          OH    Online          0.25
Ohio          OH    Out-of-State    0.25
Ohio          OH    Net Shortfall   2.2
Conn.         CT    Online          0.1
Conn.         CT    Out-of-State    0.1
Conn.         CT    Net Shortfall   2.5
Wash.         WA    Online          0.3
Wash.         WA    Out-of-State    0.3
Wash.         WA    Net Shortfall   1.6
N Carolina    NC    Online          0.2
N Carolina    NC    Out-of-State    0.2
N Carolina    NC    Net Shortfall   1.5
Virginia      VA    Online          0.2
Virginia      VA    Out-of-State    0.2
Virginia      VA    Net Shortfall   1.3
Mass.         MA    Online          0.15
Mass.         MA    Out-of-State    0.15
Mass.         MA    Net Shortfall   1.2
Louisiana     LA    Online          0.3
Louisiana     LA    Out-of-State    0.4
Louisiana     LA    Net Shortfall   0.7
Wisconsin     WI    Online          0.1
Wisconsin     WI    Out-of-State    0.15
Wisconsin     WI    Net Shortfall   1.0
Arizona       AZ    Online          0.3
Arizona       AZ    Out-of-State    0.3
Arizona       AZ    Net Shortfall   0.5
Maryland      MD    Online          0.1
Maryland      MD    Out-of-State    0.1
Maryland      MD    Net Shortfall   0.8
Georgia       GA    Online          0.3
Georgia       GA    Out-of-State    0.4
Georgia       GA    Net Shortfall   0.3
Nevada        NV    Online          0.3
Nevada        NV    Out-of-State    0.3
Nevada        NV    Net Shortfall   0.3
;
run;

%let numTopStates = 14;
%let baseRadius = 2.0;

/*--Compute vector end points for the first 14 states--*/
data state1;
  retain theta 0 this &baseRadius prev;
  set state_online (obs= %eval(3 * &numTopStates));

  if mod(_N_, 3) NE 0 then stateAbbr="";
 
  prev = this;
  this = prev + amount;
  output;

%let PI = %sysfunc(constant(PI));
  if mod(_N_, 3) = 0 then do;
    theta = theta + 2 * &PI / &numTopStates;
    this = &baseRadius;
  end;

run;


data revenue;
  set state1 end=last;
  length circLabel $7;
  keep state case x1 y1 x2 y2 stLabelX stLabelY cLabelX stateAbbr radius circLabel;

  xProject = cos(theta);
  yProject = sin(theta);

  /* vector origin */
  x1=prev*xProject;
  y1=prev*yProject;

  /* vector end */
  x2=this*xProject;
  y2=this*yProject;

%let labelOffset = 0.7;
  stLabelX=(this + &labelOffset)*xProject;
  stLabelY=(this + &labelOffset)*yProject;

  radius=&baseRadius;
  output;

  /* Reference circles */
  if last=1 then
  do;
    state=''; stateAbbr=''; case='';
    x1=.; y1=.; x2=.; y2=.; stLabelX=.; stLabelY=.;
    do radius=7 to 32 by 5;
      clabelX=-2.2;
      circLabel=put(radius - &baseRadius, 2.);
      circLabel=cat('$', strip(cat(strip(circLabel),' B')));
      output;
    end;
  end;
  run;

proc template;
   define style styles.rev_shortfall;
      parent = Styles.listing;
      class GraphColors
         "Abstract colors used in graph styles" /

         'gcdata1' = cx3f3f6f
         'gcdata2' = cx9f9f1f
         'gcdata3' = sienna

         'gdata1' = cx7f7f9f
         'gdata2' = cxffaf1f
         'gdata3' = cxff1f1f
         ;
   end;
run;

proc template;
  define statgraph revenue_shortfall;
    beginGraph / designHeight=640;
      entryTitle 'Top Revenue Shortfall by State';

      layout overlayEquated / xaxisopts=(display=none offsetmin=0 offsetmax=0)
                              yaxisopts=(display=none offsetmin=0 offsetmax=0.03);

        ellipseParm semimajor=radius semiminor=radius slope=0 xorigin=0 yorigin=0 / 
                          display=(fill outline) clip=true datatransparency=0.7
                          fillAttrs=(transparency=0.8); 

        vectorPlot x=y2 y=x2 xorigin=y1 yorigin=x1 / group=case arrowheads=false name='v'
                          lineattrs=(pattern=solid thickness=12) includeMissingGroup=false;
        ellipseParm semimajor=2.1 semiminor=2.1 slope=0 xorigin=0 yorigin=0 / 
                          display=all fillAttrs=(color=darkGray);

        scatterPlot x=stLabelY y=stLabelX / markercharacter=stateAbbr markercharacterattrs=GraphValueText;
        scatterPlot x=cLabelX y=eval(radius + 0.4) / markercharacter=circLabel
                          markercharacterattrs=GraphValueText;
        
        referenceLine y=-6.8 / datatransparency=1;

        discreteLegend 'v' / location=inside valign=top halign=right across=1 
                             valueattrs=(size=10) pad=(left=5);

      endLayout;

      entryFootnote halign=left textattrs=(size=7) 
            'This graph uses GTL to recreate a similar graph seen in Time Magazine.';
    endGraph;
  end;
run;

ods html style=styles.rev_shortfall;
ods graphics /  height=600px imagename='Revenue_shortfall';
proc sgrender data=revenue template=revenue_shortfall;
run;



