Data state_online;
  input State $1-10 StateAb $15-20 Case $21-35 Amount;
  format Amount dollar6.0;
  label amount='Amount in Billions';
  if case='Catalog' then case='Out-of-State';
  /*--CA Short Fall is really 23--*/
  datalines;
California    CA    Online          2.0 
California    CA    Catalog         2.2
California    CA    Net Shortfall   23.0  
New Jersey    NJ    Online          0.2
New Jersey    NJ    Catalog         0.2
New Jersey    NJ    Net Shortfall   9.6
New York      NY    Online          0.9
New York      NY    Catalog         1.0
New York      NY    Net Shortfall   8.1
Texas         TX    Online          0.9
Texas         TX    Catalog         1.0
Texas         TX    Net Shortfall   6.0
Illinois      IL    Online          0.4
Illinois      IL    Catalog         0.7
Illinois      IL    Net Shortfall   4.3
Minnesotta    MN    Online          0.2
Minnesotta    MN    Catalog         0.2
Minnesotta    MN    Net Shortfall   3.0
Florida       FL    Online          0.7
Florida       FL    Catalog         0.6
Florida       FL    Net Shortfall   2.1
Penn.         PA    Online          0.3
Penn.         PA    Catalog         0.3
Penn.         PA    Net Shortfall   2.8
Ohio          OH    Online          0.25
Ohio          OH    Catalog         0.25
Ohio          OH    Net Shortfall   2.2
Conn.         CT    Online          0.1
Conn.         CT    Catalog         0.1
Conn.         CT    Net Shortfall   2.5
Wash.         WA    Online          0.3
Wash.         WA    Catalog         0.3
Wash.         WA    Net Shortfall   1.6
N Carolina    NC    Online          0.2
N Carolina    NC    Catalog         0.2
N Carolina    NC    Net Shortfall   1.5
Virginia      VA    Online          0.2
Virginia      VA    Catalog         0.2
Virginia      VA    Net Shortfall   1.3
Mass.         MA    Online         0.15
Mass.         MA    Catalog         0.15
Mass.         MA    Net Shortfall   1.2
Luisiana      LA    Online          0.3
Luisiana      LA    Catalog         0.4
Luisiana      LA    Net Shortfall   0.7
Wisconsin     WI    Online          0.1
Wisconsin     WI    Catalog        0.15
Wisconsin     WI    Net Shortfall   1.0
Arizona       AZ    Online          0.3
Arizona       AZ    Catalog         0.3
Arizona       AZ    Net Shortfall   0.5
Maryland      MD    Online          0.1
Maryland      MD    Catalog         0.1
Maryland      MD    Net Shortfall   0.8
Georgia       GA    Online          0.3
Georgia       GA    Catalog         0.4
Georgia       GA    Net Shortfall   0.3
Nevada        NV    Online          0.3
Nevada        NV    Catalog         0.3
Nevada        NV    Net Shortfall   0.3
;
run;
/*proc print;run;*/

data _null_;
  call symput ("count", count/3);
  set state_online (obs=42) nobs=count;
  stop;
  run;

/*--Compute vector end points for the first 14 states--*/
data state1;
  retain PI 3.14159265;
  retain theta 0 prev 2 this 2;
  set state_online (obs=42);
  N=_n_;

  if ~mod(_N_, 3)=0 then stateAb="";
 
  this=prev+amount;
  output;
  prev=this;

  if mod(_N_, 3)=0 then do;
/*    theta=theta+2*PI/&count;*/
    theta=theta+2*PI/14;
  prev=2;
  this=2;
  end;
run;
/*proc print;run;*/

data state2;
  set state1 end=last;
  length label $7;
  keep state case x1 y1 x2 y2 xc yc xe stateAb radius label;
  x1=(prev)*cos(theta);
  y1=(prev)*sin(theta);
  x2=(this)*cos(theta);
  y2=(this)*sin(theta);
  xc=(this+0.6)*cos(theta);
  yc=(this+0.6)*sin(theta);
  radius=2;
  output;
  if last=1 then do;
    state=''; stateAb=''; case=''; x1=.; y1=.; x2=.; y2=.; xc=.; yc=.;
    do radius=7 to 32 by 5;
    xe=-2;
    label=put(radius-2, 2.);
    label=cat('$', strip(cat(strip(label),' B')));
      output;
  end;
  end;
  run;
/*proc print;run;*/

proc template;
   define style styles.Online;
      parent = Styles.listing;
      class GraphColors
         "Abstract colors used in graph styles" /

         'gcdata3' = cx3f3f6f
         'gcdata2' = cx9f9f1f
         'gcdata1' = cx9f1010

         'gdata3' = cx7f7f9f
         'gdata2' = cxffaf1f
         'gdata1' = cxff1f1f
         ;
   end;
run;

proc template;
  define statgraph revenue_shortfall;
    begingraph / designHeight=640;
    entrytitle 'Top Revenue Shortfall by State';
    entryfootnote halign=left textattrs=(size=7) 
                    'This graph uses GTL to recreate a similar graph seen in Time Magazine.';
    layout overlayequated / xaxisopts=(display=none offsetmin=0 offsetmax=0)
                       yaxisopts=(display=none offsetmin=0.0 offsetmax=0.01);
        ellipseparm semimajor=radius semiminor=radius slope=0 xorigin=0 yorigin=0 / 
                    datatransparency=0.7 display=(fill outline) clip=true; 
        ellipseparm semimajor=radius semiminor=radius slope=0 xorigin=0 yorigin=0 / 
                    datatransparency=0.8 display=(outline) clip=true;
        vectorplot x=y2 y=x2 xorigin=y1 yorigin=x1 / group=case arrowheads=false 
               lineattrs=(pattern=solid thickness=20) includemissinggroup=false name='v';
    vectorplot x=y2 y=x2 xorigin=y1 yorigin=x1 / arrowheads=false 
               lineattrs=(pattern=solid thickness=15 color=white) datatransparency=0.8;
    vectorplot x=y2 y=x2 xorigin=y1 yorigin=x1 / arrowheads=false 
               lineattrs=(pattern=solid thickness=9 color=white) datatransparency=0.8;
    vectorplot x=y2 y=x2 xorigin=y1 yorigin=x1 / arrowheads=false 
               lineattrs=(pattern=solid thickness=3 color=white) datatransparency=0.7;
        scatterplot x=yc y=xc / markercharacter=stateab markercharacterattrs=(size=8);
    scatterplot x=xe y=radius / markercharacter=label markercharacterattrs=(size=10) ;
      discretelegend 'v' / location=inside valign=top halign=right across=1 
                             valueattrs=(size=10) pad=(left=5);
    drawimage "shop_cart.png" 
                   / x=0 y=0 drawspace=datavalue anchor=center width=5 sizeunit=data scale=fitwidth;
        drawoval x=0 y=0 width=4.2 height=4.2 / drawspace=datavalue widthunit=data heightunit=data
                 outlineattrs=(thickness=4 color=gray);
    referenceline y=-6.5 / datatransparency=1;

    drawrectangle x=60  y=80 width=37.5 height=18 / drawspace=graphpercent  
                      display=(fill outline) fillattrs=(color=white) outlineattrs=(thickness=1)
                      anchor=topleft transparency=0;
        drawtext textattrs=(size=14) "E-tail Envy" / x=62 y=82 width=20 
                 widthunit=percent anchor=topleft justify=left; 
        drawtext textattrs=(size=8) "Strapped states want Amazon and other sellers to collect " 
                 "sales tax.  As states have labored to close the painful budget shortfalls "
                 "totaling $103 billion nationwide, the race to tap a hefty untapped revenue source "
                 "- sales tax from online sellers - is picking up speed." 
                 / x=62 y=78 width=36 widthunit=percent anchor=topleft justify=left;

    endlayout;
  endgraph;
  end;
run;

ods html style=styles.Online;
ods graphics / reset noscale  imagename='Revenue_shortfall_tweaked';
proc sgrender data=state2 template=revenue_shortfall;
run;
