
data nodes;
 input xvar yvar size nodeId $3.;
 datalines;
3.0  21 30 1
1.5  14 30 2
4.8  14 30 7
2.4   7 30 4
;
run;

data nodeLabels;
 input xscat yscat label1 $15.;
 datalines;
 3.0  22.0 1
 3.0  21.4 Temp
 3.0  20.7 p=0.001
 1.5  14.9 2
 1.5  14.2 Wind
 1.5  13.7 p=0.002
 4.8  14.9 7
 4.8  14.2 Wind
 4.8  13.7 p=0.003
 2.4   8.0 4
 2.4   7.4 Temp
 2.4   6.7 p=0.003
;
run;

data edges;
 input x y xor yor;
 datalines;
 0.8   0 1.5  14
 1.5  14 3.0  21
 2.4   7 1.5  14
 1.9   0 2.4   7
 3     0 2.4   7
 4.8  14 3.0  21
 4.2   0 4.8  14
 5.4   0 4.8  14
;
run;

data box;
 do i=1 to 20;
 y1=abs(rannor(9273)*50);
 y2=abs(rannor(9273)*50);
 y3=abs(rannor(9273)*50);
 y4=abs(rannor(9273)*50);
 y5=abs(rannor(9273)*50);
 output;
 end;
run;

data cr_tree;
 merge nodes nodeLabels edges box;
run;

proc template;
  define statgraph condRegTree;
    begingraph/ designheight=800px designwidth=700px
                backgroundColor=cxE0E7EF;

      entrytitle "Conditional Regression Tree";
      layout lattice / rows=2 rowweights=(0.6 0.4) ;

        layout overlay / walldisplay=none 
                yaxisopts=(display=none offsetmin=0.02 linearopts=(viewmin=0 viewmax=21))
                xaxisopts=(display=none offsetMin=0 offsetmax=0 linearopts=(viewmin=0 viewMax=6.2));

          vectorplot x=x y=y xorigin=xor yorigin=yor / arrowheads=false
                        lineattrs=(thickness=3 color=darkBlue);
          bubbleplot x=xvar y=yvar size=size /  display=(outline fill)
                        bubbleradiusmin=24 bubbleradiusmax=28 
                        fillattrs=(color=cxAAC0EA) dataSkin=gloss;
          scatterplot x=xscat y=yscat / markercharacter=label1
                        markerCharacterAttrs=(size=7);

%let unicodeLTEq = {unicode '2264'x};
%macro drawTextStmt(symbol, txt, x=, y=);
  drawText textAttrs=(size=7) &symbol &txt / x=&x y=&y
              drawSpace=datavalue backGroundAttrs=(transparency=0);
%mend drawTextStmt;

          %drawTextStmt(&unicodeLTEq, " 82", x=2.45, y=18.5);
          %drawTextStmt(">",          " 82", x=3.65, y=18.5);

          %drawTextStmt(&unicodeLTEq, " 6.9", x=1.30, y=10);
          %drawTextStmt(">",          " 6.9", x=2.05, y=10);

          %drawTextStmt(&unicodeLTEq, " 8.6", x=4.55, y=8);
          %drawTextStmt(">",          " 8.6", x=5.1,  y=8);

          %drawTextStmt(&unicodeLTEq, " 77", x=2.1, y=2.5);
          %drawTextStmt(">",          " 77", x=2.75, y=2.5);

        endlayout;

        layout lattice / columns=5 rowDataRange=union columnGutter=10;
          column2Headers;
            entry "Node 3 (n=10)";
            entry "Node 5 (n=48)";
            entry "Node 6 (n=21)";
            entry "Node 8 (n=27)";
            entry "Node 9 (n=10)";
          endColumn2Headers;
          rowAxes;
            rowAxis / display=(tickValues) gridDisplay=on displaySecondary=(tickValues) ;
          endRowAxes;

%let boxDisplay=(caps fill median outliers);
          boxplot y=y1 / display=&boxDisplay ;
          boxplot y=y2 / display=&boxDisplay ;
          boxplot y=y3 / display=&boxDisplay ;
          boxplot y=y4 / display=&boxDisplay ;
          boxplot y=y5 / display=&boxDisplay ;
        endLayout;
      endLayout;
      entryFootnote halign=left textattrs=(size=7)
      'This graph uses GTL to create a conditional regression tree'
      ' similar to the ones seen on the web.'; 
    endgraph;
  end;
run;

ods graphics / reset=all imagename='Conditional_Reg_Tree';
proc sgrender data=cr_tree template=condRegTree;
run;
