
data usa alaska Hawaii;
  /* Use less detailed data; remove Puerto Rico to allow barchart inset */
  set maps.states( where=(density<=1 and (state ne 72) ) );
  length id $8;
  retain xFirst yFirst;
  keep state segment x y id;
  by state segment;
  
  /*--Make unique Id for each state+segment combination--*/ 
  id=put(state, 3.0) || put(segment, 3.0);

  /*--Save away the first vertex--*/
  if first.segment=1 then do;
    xFirst=x; yFirst=y;
  end;
  
  if state=2 then output alaska;
  else if state=15 then output hawaii;
  else output usa; 
 
  /*-- Close the segment polygon: Write first vertex again--*/
  if last.segment=1 then do; 
    x=xFirst; y=yFirst; 
    if state=2 then output alaska;
    else if state=15 then output hawaii;
    else output usa;
  end;

run;


data usa_map_pop;
  set usa end=last;
  drop deg2Rad lat long;
  format pop 1.0;
  length city $12;
  deg2Rad=atan(1)/45; /* Degree to radian conversion factor */
  output;

  /* Append obs for city population values to USA map data */

  if last=1 then do; /* Convert lat,long from deg,min --> x, y radians */
    segment=1;
    state=102; City='New York';   lat=40+47/60; long=73+58/60;
        x=long*deg2Rad; y=lat*deg2Rad; pop=8.1; output;
    state=103; City='Houston';    lat=29+45/60; long=95+31/60;
        x=long*deg2Rad; y=lat*deg2Rad; pop=2.1;  output;
    state=104; City='Chicago';    lat=41+50/60; long=87+37/60;
        x=long*deg2Rad; y=lat*deg2Rad; pop=2.7;  output;
    state=105; City='Los Angeles';lat=34+3/60;  long=118+15/60;
        x=long*deg2Rad; y=lat*deg2Rad; pop=3.8;  output;

  end;
run;

/*--Project each map separately--*/
proc gproject data=usa_map_pop out=usap; id state; run;
proc gproject data=alaska out=alaskap; id state; run;
proc gproject data=hawaii out=hawaiip; id state; run;

data race;
  input City2 $1-12 Race $ Value;
  format Value percent.;
  datalines;
New York     White       0.6
Los Angeles  White       0.4
Chicago      White       0.65
Houston      White       0.5
New York     Black       0.3
Los Angeles  Black       0.25
Chicago      Black       0.25
Houston      Black       0.2
New York     Hispanic    0.1
Los Angeles  Hispanic    0.35
Chicago      Hispanic    0.1
Houston      Hispanic    0.3
;
run;

data merged;
  merge usap 
        alaskap(rename=(x=ax y=ay state=astate segment=aseg id=aid))
        hawaiip(rename=(x=hx y=hy state=hstate segment=hseg id=hid))
        race;
  run;

/* Separate pop data from Map */
data mergedFinal;
  set merged;
  if city ne ' ' then do;
    xc=x; yc=y; x=.; y=.; segment=.; state=.;
    scale='Mil';
  end;
 run;



proc template;
  define statgraph MapBubbleBarInset;
    begingraph / backgroundColor=cxE0E7EF;
      entrytitle 'Population and Ethnicity of the Four Largest Cities in USA';

      legenditem type=marker name='w' / markerattrs=graphdata1(size=5 symbol=squarefilled color=graphdata1:color) label='White';
      legenditem type=marker name='b' / markerattrs=graphdata2(size=5 symbol=squarefilled color=graphdata2:color) label='Black';
      legenditem type=marker name='h' / markerattrs=graphdata3(size=5 symbol=squarefilled color=graphdata3:color) label='Hispanic';

      layout overlayequated / xaxisopts=(offsetmax=0.3 display=none) 
                              yaxisopts=(offsetmin=0.3 display=none);
        seriesplot x=x y=y / group=id lineattrs=graphdatadefault(color=cx001f4f) ;
        bubbleplot x=xc y=yc size=pop / datatransparency=0.3 datalabel=city dataskin=sheen fillattrs=graphdata1
                                 bubbleradiusmin=15 bubbleradiusmax=30 datalabelattrs=(size=9);
        scatterplot x=xc y=eval(yc+0.015) / markercharacter=pop markercharacterattrs=(size=11 weight=bold) ;
        scatterplot x=xc y=eval(yc-0.015) / markercharacter=scale markercharacterattrs=(size=7) ;

        /* Alaska */
        layout overlayequated / xaxisopts=(display=none) yaxisopts=(display=none)
                                width=25pct height=20pct halign=0.05 valign=0.1
                                walldisplay=none opaque=false ;
          seriesplot x=ax y=ay / group=aid lineattrs=graphdatadefault(color=cx001f4f);
        endlayout;

        /* Hawaii */
        layout overlayequated / xaxisopts=(display=none) yaxisopts=(display=none)
                                  width=10pct height=10pct halign=0.4 valign=0.1
                                  walldisplay=none opaque=false;
          seriesplot x=hx y=hy / group=hid lineattrs=graphdatadefault(color=cx001f4f);
        endlayout;

        /* Ethnicity bar chart */
        layout overlay / width=40pct height=30pct halign=0.95 valign=0.1 
                         walldisplay=none xaxisopts=(display=none)
                         yaxisopts=(reverse=true display=(tickvalues) tickvalueattrs=(size=5));

            entry textattrs=(size=7) "Population Breakdown by Ethnicity" / location=outside valign=top;
            barchart x=city2 y=value / group=race orient=horizontal groupdisplay=cluster 
                     barlabel=true barlabelattrs=(size=5) dataskin=pressed name='a' includemissinggroup=false;
            discretelegend 'w' 'b' 'h'/ across=3 location=outside valign=bottom
                                        valueattrs=(size=5) ;

        endlayout;
      endlayout;

      entryfootnote halign=left textattrs=(size=6) 
                   'Ethnicity data is for illustration purposes only ';

    endgraph;
  end;
run;

ods graphics / reset antialiasmax=4000 maxlegendarea=100 
               imagename='MapBubbleBarInset';
proc sgrender data=mergedFinal template=MapBubbleBarInset;
run;
