/* Data for the Milky Way transit map */
data mw_routes;
    input route $14. x y stationgrp terminus;
    datalines;
Outer         415     16  .    1
Outer         492     95  .    .
Outer         492    304  .    .
Outer         420    375  .    .
Outer         224    375  .    .
Outer         180    334  .    .
Outer         180    232  .    .
Outer         228    186  3    1
Outer         274    186  .    .
Outer         314    215  4    1
Crux-Scutum   366    414  .    1
Crux-Scutum   192    414  .    .
Crux-Scutum   155    380  .    .
Crux-Scutum   155    221  .    .
Crux-Scutum   216    162  3    1
Crux-Scutum   362    162  .    .
Crux-Scutum   390    190  .    .
Crux-Scutum   390    241  .    .
Crux-Scutum   367    264  .    .
Crux-Scutum   310    264  .    .
Crux-Scutum   286    241  4    1
Sagittarius   130    349  .    1
Sagittarius   130    210  .    .
Sagittarius   204    138  3    1
Sagittarius   378    138  .    1
Sagittarius   410    171  .    .
Sagittarius   410    256  .    .
Sagittarius   367    299  .    .
Sagittarius   296    300  .    .
Sagittarius   260    264  4    1
3-Kiloparsec  102    281  2    1
3-Kiloparsec  102    164  .    .
3-Kiloparsec  195     74  .    .
3-Kiloparsec  413     74  .    .
3-Kiloparsec  444    106  .    .
3-Kiloparsec  444    282  .    .
3-Kiloparsec  390    336  .    .
3-Kiloparsec  236    336  .    .
3-Kiloparsec  202    302  .    .
3-Kiloparsec  202    246  .    .
3-Kiloparsec  232    216  .    .
3-Kiloparsec  314    216  .    1
Orion         265    114  .    1
Orion         353    114  .    .
Orion         378    138  .    1
Suburban       64    242  2    1
Suburban       64    120  .    .
Suburban      146     35  .    1
Express       377    253  .    1
Express       395    271  .    1
Express       426    302  .    1
Express       459    336  .    1
;
run;

data mw_names;
    input xn yn name $ 13-31 ;
    datalines;
152     30  Andromeda Customs
138     56  The Hamptons
 88    108  Levittown
  6    178  Omega
 10    190  Centauri
  3    278  New Outer Junction
 65    366  Omicron Centauri
166    120  Outer Junction
228     98  Orion Nebula
336     98  Sol
230     56  Pal 2
326     56  Crab Nebula
384    120  Eagle
384    132  Nebula
380     14  M13
255    394  Nu Aquilae
373    414  TT Aquilae
461    348  Cygnus
435    301  Norma
405    271  Carina
324    240  Centaurus
332    282  W50
342    219  P Cygni
267    264  Sag A
232    230  Galactic
232    242  Center
208    288  OGLE-2005-
212    300  BLG-I69L
 50     26  Canis Major
;
run;

data mw_substations;
  input xs ys substation_grp ;
  datalines;
285    375  1
390    219  2
346    264  2
  .      .  3
235     74  4
359     74  4
202    280  4
346    114  5
 64    180  6
 82    102  6
127     55  6
;
run;

/* Y-coords were mapped from top to bottom */
data mw_merged;
    merge mw_routes mw_names mw_substations;
    y = 430 - y;
    if (yn ne .) then
      yn = 430 - yn;
    if (ys ne .) then
      ys = 430 - ys;
run;
 
 
proc template;
  define statgraph milkyWayTransit;
  begingraph;
    entrytitle "Milky Way Transit Authority";
    layout overlay / walldisplay=none yaxisopts=(display=none)
        xaxisopts=(display=none offsetmax=0.1);

      /* Galactic Center */
      ellipseparm semimajor=51 semiminor=20 slope=.88 xorigin=288 yorigin=191 /
          display=(fill) fillAttrs=(color=cxFDFDB0);
      /* Canis Major */
      ellipseparm semimajor=100 semiMinor=50 slope=-.70 xorigin=130 yorigin=334 / 
          display=(fill) fillattrs=(color=cxFDFDB0);

      /* Main routes */
      seriesplot x=x y=y / name="routes" includemissinggroup=false
          group=route lineattrs=(thickness=1.8% pattern=solid)
          dataTransparency=0.2;

      /* Transfer outline */
      seriesplot x=x y=y / group=stationgrp includemissinggroup=false display=all
          lineattrs=(thickness=1.8% pattern=solid color=black)
          markerAttrs=(size=3.0% symbol=circlefilled color=black);
      /* Terminal outline */
      scatterplot x=x y=y / group=terminus includemissinggroup=false
          markerattrs=(size=3.0% symbol=circlefilled color=black);

%let bgColor=white;
      /* Transfer fill */
      seriesplot x=x y=y / group=stationgrp includemissinggroup=false
          lineattrs=(thickness=0.8% pattern=solid color=&bgColor);
      /* Terminal fill */
      scatterplot x=x y=y / group=terminus includemissinggroup=false
          markerattrs=(size=2.0% symbol=circlefilled color=&bgColor);


      /* Substations */
      scatterplot x=xs y=ys / group=substation_grp includemissinggroup=false
          markerattrs=(size=3.0% symbol=squareFilled);
      /* Substations fill */
      scatterplot x=xs y=ys / group=substation_grp includemissinggroup=false
          markerattrs=(size=2.0% symbol=square color=&bgColor);

      /* Terminal/Sub Labels */
      scatterplot x=xn y=yn / group=name includemissinggroup=false 
          markerattrs=(size=0) datalabelattrs=(color=grey size=8)
          datalabel=name datalabelposition=right;

      /* Legend */
      discretelegend "routes" / border=false;
    endlayout;
    entryfootnote halign=right 
        "As seen on: http://arbesman.net/milkyway/" / textattrs=GraphDataText;
  endgraph;
 end;
run;

ods graphics / reset imagename='MilkyWayTransit' ;
proc sgrender template=milkyWayTransit data=mw_merged;
run;
