/*
 * Parallel axis plot example
 */

/* Set min, max for each variable */
%let min_v1 = 0;    %let max_v1 = 50;   /* mpg_city */
%let min_v2 = 0;    %let max_v2 = 50;   /* mpg_highway */
%let min_v3 = 2000; %let max_v3 = 7000; /* weight */
%let min_v4 = 0;    %let max_v4 = 500;  /* horsepower */

/* Calculate the ranges */
%let range_v1 = %sysevalf(&max_v1 - &min_v1);
%let range_v2 = %sysevalf(&max_v2 - &min_v2);
%let range_v3 = %sysevalf(&max_v3 - &min_v3);
%let range_v4 = %sysevalf(&max_v4 - &min_v4);

/* Normalize the values */
data par_axis_norm;
  set sashelp.cars(where=(type ne 'Hybrid'));
  x1 = 1;
  x2 = 2;
  x3 = 3;
  x4 = 4;
  mpg_city_pct = (mpg_city - &min_v1) / &range_v1;
  mpg_highway_pct = (mpg_highway - &min_v2) / &range_v2;
  weight_pct = (weight - &min_v3) / &range_v3;
  horsepower_pct = (horsepower - &min_v4) / &range_v4;
run;

data y_axis_ticks;
  drop i increment;
  attrib tvalue format=Best4.;
  axis_x = 1; axis_y = 0;
  tvalue=&min_v1;
  increment = 0.2 * &range_v1;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 2; axis_y = 0;
  tvalue=&min_v2;
  increment = 0.2 * &range_v2;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 3; axis_y = 0;
  tvalue=&min_v3;
  increment = 0.2 * &range_v3;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;

  axis_x = 4; axis_y = 0;
  tvalue=&min_v4;
  increment = 0.2 * &range_v4;
  output;
  do i=1 to 5;
    axis_y = axis_y + 0.2;
    tvalue = tvalue + increment;
    output;
  end;
run;

/* X axis labels */
data x_axis_labels;
  input pos label $15.;
  cards;
  1   MPG City
  2   MPG Hwy
  3   Weight
  4   Horsepower
;
run;

data par_axis_final;
  merge par_axis_norm y_axis_ticks x_axis_labels;
run;

proc template;
  define statgraph par_axis_plot;
    begingraph / backgroundColor=cxE0E7EF;
      entrytitle 'Automobile Attributes for 2004';
      layout overlay / wallDisplay=(fill)
            xaxisOpts=(display=none offsetMin=0.02 offsetMax=0.02)
            yAxisOpts=(display=none offsetMin=0.03 offsetMax=0.02);

%let vectorOpts=group=origin lineAttrs=(pattern=solid thickness=3)
                            arrowHeads=false dataTransparency=0.5;
          vectorPlot xOrigin=x1 yOrigin=mpg_city_pct x=x2 y=mpg_highway_pct /
                &vectorOpts;
          vectorPlot xOrigin=x2 yOrigin=mpg_highway_pct x=x3 y=weight_pct /
                &vectorOpts;
          vectorPlot xOrigin=x3 yOrigin=weight_pct x=x4 y=horsepower_pct /
                &vectorOpts name="p1";
          referenceLine x=pos / lineAttrs=(color=gray thickness=26)
                dataTransparency=0.6 ;
          referenceLine x=pos / lineAttrs=(color=white thickness=22)
                dataTransparency=0.4 curveLabel=label curveLabelPosition=min;

          scatterPlot x= axis_x y = axis_y / markerCharacter=tvalue markerCharacterAttrs=(size=6 weight=bold);

          discreteLegend "p1" / title="Origin" border=false pad=5;
      endlayout;
      entryFootnote halign=left textattrs=(size=7)
        'This parallel axis graph was created using GTL.';
    endgraph;
  end;
run;
ods graphics / reset imagename='parallelAxis';
proc sgrender data=par_axis_final template=par_axis_plot;
run;
